Siebrand has uploaded a new change for review.

  https://gerrit.wikimedia.org/r/52018


Change subject: Use American English spelling for behavior
......................................................................

Use American English spelling for behavior

Change-Id: Id13d1110c08d43d968fc7dad1ae319da14324539
---
M client/tests/phpunit/includes/EntityCacheUpdaterTest.php
M client/tests/selenium/interwiki/client_repo_spec.rb
M client/tests/selenium/interwiki/interwiki_spec.rb
M lib/includes/claim/Claim.php
M lib/includes/entity/Entity.php
M lib/includes/snak/Snak.php
M lib/includes/snak/Snaks.php
M lib/resources/wikibase.ui.PropertyEditTool.css
M lib/resources/wikibase.ui.Toolbar.EditGroup.js
M repo/includes/api/GetEntities.php
M repo/includes/store/sql/TermSqlCache.php
M repo/includes/updates/EntityDeletionUpdate.php
M repo/includes/updates/EntityModificationUpdate.php
M repo/tests/phpunit/includes/content/EntityHandlerTest.php
M repo/tests/selenium/aliases/aliases_spec.rb
M repo/tests/selenium/item/description_spec.rb
M repo/tests/selenium/item/edit_conflict_spec.rb
M repo/tests/selenium/item/label_spec.rb
M repo/tests/selenium/special/create_item_spec.rb
M repo/tests/selenium/special/create_property_spec.rb
M repo/tests/selenium/statements/references_spec.rb
M repo/tests/selenium/statements/statements_spec.rb
22 files changed, 37 insertions(+), 37 deletions(-)


  git pull ssh://gerrit.wikimedia.org:29418/mediawiki/extensions/Wikibase 
refs/changes/18/52018/1

diff --git a/client/tests/phpunit/includes/EntityCacheUpdaterTest.php 
b/client/tests/phpunit/includes/EntityCacheUpdaterTest.php
index 6345b02..0494461 100644
--- a/client/tests/phpunit/includes/EntityCacheUpdaterTest.php
+++ b/client/tests/phpunit/includes/EntityCacheUpdaterTest.php
@@ -70,7 +70,7 @@
 
                        $cacheUpdater->handleChange( $change );
 
-                       // TODO: test if the result matches expected behaviour
+                       // TODO: test if the result matches expected behavior
                        $this->assertTrue( true );
                }
        }
diff --git a/client/tests/selenium/interwiki/client_repo_spec.rb 
b/client/tests/selenium/interwiki/client_repo_spec.rb
index dff16e8..d258ef4 100644
--- a/client/tests/selenium/interwiki/client_repo_spec.rb
+++ b/client/tests/selenium/interwiki/client_repo_spec.rb
@@ -100,7 +100,7 @@
     end
   end
 
-  context "client-repo check behaviour on changing connecting sitelink" do
+  context "client-repo check behavior on changing connecting sitelink" do
     it "should change the connecting sitelink to a nonexisting article" do
       on_page(ItemPage) do |page|
         page.navigate_to_item
diff --git a/client/tests/selenium/interwiki/interwiki_spec.rb 
b/client/tests/selenium/interwiki/interwiki_spec.rb
index bcd0051..029b2d9 100644
--- a/client/tests/selenium/interwiki/interwiki_spec.rb
+++ b/client/tests/selenium/interwiki/interwiki_spec.rb
@@ -43,7 +43,7 @@
         page.clientEditLinksLink?.should be_true
       end
     end
-    it "should check correct behaviour of editLinks-Link" do
+    it "should check correct behavior of editLinks-Link" do
       on_page(ClientPage) do |page|
         page.navigate_to_article(article_title)
         page.clientEditLinksLink
@@ -56,7 +56,7 @@
     end
   end
 
-  context "Check noexternallanglinks magic word behaviour" do
+  context "Check noexternallanglinks magic word behavior" do
     it "should check noexternallanglinks zh|af" do
       on_page(ClientPage) do |page|
         page.change_article(article_title, article_text + nell_zhaf)
diff --git a/lib/includes/claim/Claim.php b/lib/includes/claim/Claim.php
index 1159f60..bcb48fe 100644
--- a/lib/includes/claim/Claim.php
+++ b/lib/includes/claim/Claim.php
@@ -171,7 +171,7 @@
         * Roundtrips with Claim::newFromArray
         *
         * This method can be used for serialization when passing the array to 
for
-        * instance json_encode which created behaviour similar to
+        * instance json_encode which created behavior similar to
         * @see Serializable::serialize but different in that it uses the
         * type identifiers rather then class names.
         *
@@ -243,4 +243,4 @@
 /**
  * @deprecated since 0.4. Use Claim instead.
  */
-class ClaimObject extends Claim {}
\ No newline at end of file
+class ClaimObject extends Claim {}
diff --git a/lib/includes/entity/Entity.php b/lib/includes/entity/Entity.php
index 1ec56c9..3dce23e 100644
--- a/lib/includes/entity/Entity.php
+++ b/lib/includes/entity/Entity.php
@@ -104,7 +104,7 @@
        public function serialize() {
                $data = $this->toArray();
 
-               // Add an identifier for the serialization version so we can 
switch behaviour in
+               // Add an identifier for the serialization version so we can 
switch behavior in
                // the unserializer to avoid breaking compatibility after 
certain changes.
                $data['v'] = 1;
 
@@ -869,7 +869,7 @@
         * @param Patcher $patcher
         */
        protected function patchSpecificFields( EntityDiff $patch, Patcher 
$patcher ) {
-               // No-op, meant to be overridden in deriving classes to add 
specific behaviour
+               // No-op, meant to be overridden in deriving classes to add 
specific behavior
        }
 
        /**
diff --git a/lib/includes/snak/Snak.php b/lib/includes/snak/Snak.php
index 6fecd73..a80403a 100644
--- a/lib/includes/snak/Snak.php
+++ b/lib/includes/snak/Snak.php
@@ -54,7 +54,7 @@
         * Roundtrips with SnakObject::newFromArray
         *
         * This method can be used for serialization when passing the array to 
for
-        * instance json_encode which created behaviour similar to
+        * instance json_encode which created behavior similar to
         * @see Serializable::serialize but different in that it uses the
         * snak type identifier rather then it's class name.
         *
@@ -64,4 +64,4 @@
         */
        public function toArray();
 
-}
\ No newline at end of file
+}
diff --git a/lib/includes/snak/Snaks.php b/lib/includes/snak/Snaks.php
index 59b0ccc..e42f8e8 100644
--- a/lib/includes/snak/Snaks.php
+++ b/lib/includes/snak/Snaks.php
@@ -98,7 +98,7 @@
         * Roundtrips with SnakList::newFromArray
         *
         * This method can be used for serialization when passing the array to 
for
-        * instance json_encode which created behaviour similar to
+        * instance json_encode which created behavior similar to
         * @see Serializable::serialize but different in that it uses the
         * snak type identifier rather then it's class name.
         *
diff --git a/lib/resources/wikibase.ui.PropertyEditTool.css 
b/lib/resources/wikibase.ui.PropertyEditTool.css
index 5ec22d8..78e9cc0 100644
--- a/lib/resources/wikibase.ui.PropertyEditTool.css
+++ b/lib/resources/wikibase.ui.PropertyEditTool.css
@@ -249,7 +249,7 @@
        .wb-error .tipsy-inner {
                background-color: #FFDFC9;
                /* on some host-client combinations the background image is 
propagated to the inner tooltip
-               container creating a background pattern; this broken behaviour 
is surpressed by explicitly
+               container creating a background pattern; this broken behavior 
is surpressed by explicitly
                setting the background image to none; this, however, has to be 
done in a separate definition
                after setting the background colour */
                background-image: none;
diff --git a/lib/resources/wikibase.ui.Toolbar.EditGroup.js 
b/lib/resources/wikibase.ui.Toolbar.EditGroup.js
index 780f149..1b6af9e 100644
--- a/lib/resources/wikibase.ui.Toolbar.EditGroup.js
+++ b/lib/resources/wikibase.ui.Toolbar.EditGroup.js
@@ -139,7 +139,7 @@
                } ) );
                // initialize the tooltip just to be able to change render 
variables like gravity
                this.tooltipAnchor.setTooltip( '' );
-               this.tooltipAnchor.stateChangeable = false; // tooltip anchor 
has no disabled/enabled behaviour
+               this.tooltipAnchor.stateChangeable = false; // tooltip anchor 
has no disabled/enabled behavior
 
                // now create the buttons we need for basic editing:
                var Button = wb.ui.Toolbar.Button,
diff --git a/repo/includes/api/GetEntities.php 
b/repo/includes/api/GetEntities.php
index ae2ba9e..cfac791 100644
--- a/repo/includes/api/GetEntities.php
+++ b/repo/includes/api/GetEntities.php
@@ -130,7 +130,7 @@
                        $this->dieUsage( "Invalid id: $id", 'no-such-entity-id' 
);
                }
 
-               // key should be numeric to get the correct behaviour
+               // key should be numeric to get the correct behavior
                // note that this setting depends upon 
"setIndexedTagName_internal"
                //FIXME: if we get different kinds of entities at once, 
$entityId->getNumericId() may not be unique.
                $entityPath = array(
diff --git a/repo/includes/store/sql/TermSqlCache.php 
b/repo/includes/store/sql/TermSqlCache.php
index a43376b..7da45c4 100644
--- a/repo/includes/store/sql/TermSqlCache.php
+++ b/repo/includes/store/sql/TermSqlCache.php
@@ -754,7 +754,7 @@
         * Takes the result of a query with joins and turns it into a row per 
term.
         *
         * Also ditches any successive results PDO manages to add to the first 
one,
-        * so the behaviour appears to be the same as when running the query 
against
+        * so the behavior appears to be the same as when running the query 
against
         * the database directly without PDO messing the the result up.
         *
         * @since 0.2
diff --git a/repo/includes/updates/EntityDeletionUpdate.php 
b/repo/includes/updates/EntityDeletionUpdate.php
index f51436e..4b82a44 100644
--- a/repo/includes/updates/EntityDeletionUpdate.php
+++ b/repo/includes/updates/EntityDeletionUpdate.php
@@ -97,7 +97,7 @@
         * @param Entity $entity
         */
        protected function doTypeSpecificStuff( Store $store, Entity $entity ) {
-               // Override to add behaviour.
+               // Override to add behavior.
        }
 
 }
diff --git a/repo/includes/updates/EntityModificationUpdate.php 
b/repo/includes/updates/EntityModificationUpdate.php
index 3f0d570..1d519d7 100644
--- a/repo/includes/updates/EntityModificationUpdate.php
+++ b/repo/includes/updates/EntityModificationUpdate.php
@@ -98,7 +98,7 @@
         * @param Entity $entity
         */
        protected function doTypeSpecificStuff( Store $store, Entity $entity ) {
-               // Override to add behaviour.
+               // Override to add behavior.
        }
 
 }
diff --git a/repo/tests/phpunit/includes/content/EntityHandlerTest.php 
b/repo/tests/phpunit/includes/content/EntityHandlerTest.php
index 3d38164..f6f7f6c 100644
--- a/repo/tests/phpunit/includes/content/EntityHandlerTest.php
+++ b/repo/tests/phpunit/includes/content/EntityHandlerTest.php
@@ -134,7 +134,7 @@
                $title = \Title::makeTitle( $handler->getEntityNamespace(), 
"1234567" );
 
                //NOTE: currently, this tests whether getPageLanguage will 
always return the content language, even
-               //      if the user language is different. It's unclear whether 
this is actually the desired behaviour,
+               //      if the user language is different. It's unclear whether 
this is actually the desired behavior,
                //      since Wikibase Entities are inherently multilingual, so 
they have no actual "page language".
 
                // test whatever is there
diff --git a/repo/tests/selenium/item/description_spec.rb 
b/repo/tests/selenium/item/description_spec.rb
index fa4246c..5457f9f 100644
--- a/repo/tests/selenium/item/description_spec.rb
+++ b/repo/tests/selenium/item/description_spec.rb
@@ -22,7 +22,7 @@
   end
 
   context "Check for item description UI" do
-    it "should check behaviour of cancel-link" do
+    it "should check behavior of cancel-link" do
       on_page(ItemPage) do |page|
         page.entityDescriptionSpan.should be_true
         page.entityDescriptionSpan.should == description
@@ -43,7 +43,7 @@
         page.entityDescriptionSpan.should == description
       end
     end
-    it "should check behaviour of ESC-key" do
+    it "should check behavior of ESC-key" do
       on_page(ItemPage) do |page|
         page.editDescriptionLink
         page.descriptionInputField = description_changed
@@ -101,7 +101,7 @@
         page.entityDescriptionSpan.should == description_normalized
       end
     end
-    it "should check for correct behaviour on '0'" do
+    it "should check for correct behavior on '0'" do
       on_page(ItemPage) do |page|
         page.navigate_to_item
         page.wait_for_entity_to_load
diff --git a/repo/tests/selenium/item/edit_conflict_spec.rb 
b/repo/tests/selenium/item/edit_conflict_spec.rb
index 8c6ce4c..981a4f2 100644
--- a/repo/tests/selenium/item/edit_conflict_spec.rb
+++ b/repo/tests/selenium/item/edit_conflict_spec.rb
@@ -28,7 +28,7 @@
     end
   end
 
-  context "check behaviour on edit conflicts (descriptions)" do
+  context "check behavior on edit conflicts (descriptions)" do
     it "should login as user 1, change description and save revid" do
       visit_page(RepoLoginPage) do |page|
         page.login_with(WIKI_ORDINARY_USERNAME, WIKI_ORDINARY_PASSWORD)
@@ -121,7 +121,7 @@
     end
   end
 
-  context "check normal behaviour" do
+  context "check normal behavior" do
     it "should be possible to edit description again after a reload" do
       on_page(ItemPage) do |page|
         page.navigate_to_item
@@ -138,7 +138,7 @@
     end
   end
 
-  context "check behaviour on edit conflicts (claims)" do
+  context "check behavior on edit conflicts (claims)" do
     prop_label = generate_random_string(10)
     prop_description = generate_random_string(20)
     prop_datatype = "Commons media file"
diff --git a/repo/tests/selenium/item/label_spec.rb 
b/repo/tests/selenium/item/label_spec.rb
index f14150c..cd935a9 100644
--- a/repo/tests/selenium/item/label_spec.rb
+++ b/repo/tests/selenium/item/label_spec.rb
@@ -22,7 +22,7 @@
   end
 
   context "Check for edit label" do
-    it "should check behaviour of cancel-link" do
+    it "should check behavior of cancel-link" do
       on_page(ItemPage) do |page|
         page.firstHeading.should be_true
         page.entityLabelSpan.should be_true
@@ -44,7 +44,7 @@
         page.entityLabelSpan.should == label
       end
     end
-    it "should check behaviour of ESC-key" do
+    it "should check behavior of ESC-key" do
       on_page(ItemPage) do |page|
         page.editLabelLink
         page.labelInputField = label_changed
@@ -104,7 +104,7 @@
         page.entityLabelSpan.should == label_normalized
       end
     end
-    it "should check for correct behaviour on '0'" do
+    it "should check for correct behavior on '0'" do
       on_page(ItemPage) do |page|
         page.navigate_to_item
         page.wait_for_entity_to_load
diff --git a/repo/tests/selenium/special/create_item_spec.rb 
b/repo/tests/selenium/special/create_item_spec.rb
index f6732b3..b292580 100644
--- a/repo/tests/selenium/special/create_item_spec.rb
+++ b/repo/tests/selenium/special/create_item_spec.rb
@@ -71,7 +71,7 @@
     end
   end
 
-  context "create check error behaviour on item creation" do
+  context "create check error behavior on item creation" do
     it "should fail to create item with empty label & description" do
       visit_page(CreateItemPage) do |page|
         page.createEntitySubmit
diff --git a/repo/tests/selenium/special/create_property_spec.rb 
b/repo/tests/selenium/special/create_property_spec.rb
index babc93b..ecfa2f5 100644
--- a/repo/tests/selenium/special/create_property_spec.rb
+++ b/repo/tests/selenium/special/create_property_spec.rb
@@ -56,7 +56,7 @@
     end
   end
 
-  context "create property error behaviour" do
+  context "create property error behavior" do
     it "should fail to create item with empty label & description" do
       visit_page(NewPropertyPage) do |page|
         page.createEntitySubmit
diff --git a/repo/tests/selenium/statements/references_spec.rb 
b/repo/tests/selenium/statements/references_spec.rb
index 543f5a1..ab07bef 100644
--- a/repo/tests/selenium/statements/references_spec.rb
+++ b/repo/tests/selenium/statements/references_spec.rb
@@ -63,7 +63,7 @@
   end
 
   context "Check references UI" do
-    it "should check references buttons behaviour" do
+    it "should check references buttons behavior" do
       on_page(ItemPage) do |page|
         page.navigate_to items[0]["url"]
         page.wait_for_entity_to_load
diff --git a/repo/tests/selenium/statements/statements_spec.rb 
b/repo/tests/selenium/statements/statements_spec.rb
index 947ca9e..a5b076d 100644
--- a/repo/tests/selenium/statements/statements_spec.rb
+++ b/repo/tests/selenium/statements/statements_spec.rb
@@ -57,7 +57,7 @@
   end
 
   context "Check statements UI" do
-    it "should check statement buttons behaviour" do
+    it "should check statement buttons behavior" do
       on_page(ItemPage) do |page|
         page.navigate_to items[0]["url"]
         page.wait_for_entity_to_load
@@ -76,7 +76,7 @@
         page.statementValueInput?.should be_false
       end
     end
-    it "should check snaktype selector behaviour", :exclude_firefox => true do
+    it "should check snaktype selector behavior", :exclude_firefox => true do
       on_page(ItemPage) do |page|
         page.navigate_to items[0]["url"]
         page.wait_for_entity_to_load
@@ -104,7 +104,7 @@
         page.snaktypeSelectorIcon?.should be_false
       end
     end
-    it "should check entity suggestor behaviour" do
+    it "should check entity suggestor behavior" do
       on_page(ItemPage) do |page|
         page.navigate_to items[0]["url"]
         page.wait_for_entity_to_load
@@ -210,7 +210,7 @@
         page.statement1ClaimValue1?.should be_false
       end
     end
-    it "should check ESC/RETURN button behaviour" do
+    it "should check ESC/RETURN button behavior" do
       on_page(ItemPage) do |page|
         page.navigate_to items[0]["url"]
         page.wait_for_entity_to_load
@@ -324,7 +324,7 @@
         page.statement1Name?.should be_false
       end
     end
-    it "should check button behaviour when editing a statement" do
+    it "should check button behavior when editing a statement" do
       on_page(ItemPage) do |page|
         page.navigate_to items[0]["url"]
         page.wait_for_entity_to_load

diff --git a/repo/tests/selenium/aliases/aliases_spec.rb 
b/repo/tests/selenium/aliases/aliases_spec.rb
index 04be7f8..2250b62 100644
--- a/repo/tests/selenium/aliases/aliases_spec.rb
+++ b/repo/tests/selenium/aliases/aliases_spec.rb
@@ -58,7 +58,7 @@
         page.cancelAliases
         page.addAliases?.should be_true
 
         # checking behaviour of ESC key
         page.addAliases
         page.aliasesInputEmpty= generate_random_string(8)
         page.aliasesInputEmpty_element.send_keys :escape
@@ -108,7 +108,7 @@
     end
   end
 
-  context "Check functionality and behaviour of aliases edit mode" do
+  context "Check functionality and behavior of aliases edit mode" do
     it "should check that the edit mode of aliases behaves properly" do
       on_page(ItemPage) do |page|
         page.wait_for_entity_to_load
@@ -58,7 +58,7 @@
         page.addAliases?.should be_true
 
-        # checking behaviour of ESC key
+        # checking behavior of ESC key
         page.addAliases
         page.aliasesInputEmpty= generate_random_string(8)
-- 
To view, visit https://gerrit.wikimedia.org/r/52018
To unsubscribe, visit https://gerrit.wikimedia.org/r/settings

Gerrit-MessageType: newchange
Gerrit-Change-Id: Id13d1110c08d43d968fc7dad1ae319da14324539
Gerrit-PatchSet: 1
Gerrit-Project: mediawiki/extensions/Wikibase
Gerrit-Branch: master
Gerrit-Owner: Siebrand <[email protected]>

_______________________________________________
MediaWiki-commits mailing list
[email protected]
https://lists.wikimedia.org/mailman/listinfo/mediawiki-commits

Reply via email to